@@ -146,7 +146,7 @@ std::vector<llvm::Pass *> LLVMVisitor::create_default_passes(int optlevel)
 #else
     passes.push_back(llvm::createInstructionCombiningPass(optlevel > 1));
 #endif
-    passes.push_back(llvm::createDeadInstEliminationPass());
+    passes.push_back(llvm::createDeadCodeEliminationPass());
     passes.push_back(llvm::createPromoteMemoryToRegisterPass());
     passes.push_back(llvm::createReassociatePass());
     passes.push_back(llvm::createGVNPass());
@@ -218,7 +218,7 @@ void LLVMVisitor::init(const vec_basic &inputs, const vec_basic &outputs,
     // Create a basic block builder with default parameters.  The builder
     // will
     // automatically append instructions to the basic block `BB'.
-    llvm::IRBuilder<> _builder = llvm::IRBuilder<>(BB);
+    llvm::IRBuilder<> _builder(BB);
     builder = reinterpret_cast<IRBuilder *>(&_builder);
     builder->SetInsertPoint(BB);
     auto fmf = llvm::FastMathFlags();
@@ -280,7 +280,7 @@ void LLVMVisitor::init(const vec_basic &inputs, const vec_basic &outputs,
     builder->CreateRetVoid();
 
     // Validate the generated code, checking for consistency.
-    llvm::verifyFunction(*F);
+    llvm::verifyFunction(*F, &llvm::outs());
 
     //     std::cout << "LLVM IR" << std::endl;
     // #if (LLVM_VERSION_MAJOR < 5)
@@ -309,9 +309,7 @@ void LLVMVisitor::init(const vec_basic &inputs, const vec_basic &outputs,
     {
     public:
         std::string &ss_;
-        MemoryBufferRefCallback(std::string &ss) : ss_(ss)
-        {
-        }
+        MemoryBufferRefCallback(std::string &ss) : ss_(ss) {}
 
         virtual void notifyObjectCompiled(const llvm::Module *M,
                                           llvm::MemoryBufferRef obj)
@@ -497,7 +495,9 @@ llvm::Function *LLVMVisitor::get_powi()
 {
     std::vector<llvm::Type *> arg_type;
     arg_type.push_back(get_float_type(&mod->getContext()));
+#if (LLVM_VERSION_MAJOR > 12)
     arg_type.push_back(llvm::Type::getInt32Ty(mod->getContext()));
+#endif
     return llvm::Intrinsic::getDeclaration(mod, llvm::Intrinsic::powi,
                                            arg_type);
 }
@@ -543,7 +543,7 @@ void LLVMVisitor::bvisit(const Pow &x)
             args.push_back(apply(*x.get_base()));
             args.push_back(apply(*x.get_exp()));
             fun = get_float_intrinsic(get_float_type(&mod->getContext()),
-                                      llvm::Intrinsic::pow, 2, mod);
+                                      llvm::Intrinsic::pow, 1, mod);
         }
     }
     auto r = builder->CreateCall(fun, args);
@@ -839,7 +839,7 @@ void LLVMVisitor::bvisit(const Min &x)
     llvm::Value *value = nullptr;
     llvm::Function *fun;
     fun = get_float_intrinsic(get_float_type(&mod->getContext()),
-                              llvm::Intrinsic::minnum, 2, mod);
+                              llvm::Intrinsic::minnum, 1, mod);
     for (auto &arg : x.get_vec()) {
         if (value != nullptr) {
             std::vector<llvm::Value *> args;
@@ -860,7 +860,7 @@ void LLVMVisitor::bvisit(const Max &x)
     llvm::Value *value = nullptr;
     llvm::Function *fun;
     fun = get_float_intrinsic(get_float_type(&mod->getContext()),
-                              llvm::Intrinsic::maxnum, 2, mod);
+                              llvm::Intrinsic::maxnum, 1, mod);
     for (auto &arg : x.get_vec()) {
         if (value != nullptr) {
             std::vector<llvm::Value *> args;
@@ -891,7 +891,8 @@ void LLVMVisitor::bvisit(const Symbol &x)
         result_ = it->second;
         return;
     }
-    throw std::runtime_error("Symbol " + x.__str__()
+
+    throw SymEngineException("Symbol " + x.__str__()
                              + " not in the symbols vector.");
 }
 
@@ -943,9 +944,9 @@ void LLVMLongDoubleVisitor::visit(const Constant &x)
 }
 #endif
 
-void LLVMVisitor::bvisit(const Basic &)
+void LLVMVisitor::bvisit(const Basic &x)
 {
-    throw std::runtime_error("Not implemented.");
+    throw NotImplementedError(x.__str__());
 }
 
 const std::string &LLVMVisitor::dumps() const
@@ -986,9 +987,7 @@ void LLVMVisitor::loads(const std::string &s)
         const std::string &s_;
 
     public:
-        MCJITObjectLoader(const std::string &s) : s_(s)
-        {
-        }
+        MCJITObjectLoader(const std::string &s) : s_(s) {}
         virtual void notifyObjectCompiled(const llvm::Module *M,
                                           llvm::MemoryBufferRef obj)
         {
@@ -1034,6 +1033,11 @@ void LLVMVisitor::bvisit(const Ceiling &x)
     result_ = r;
 }
 
+void LLVMVisitor::bvisit(const UnevaluatedExpr &x)
+{
+    apply(*x.get_arg());
+}
+
 void LLVMVisitor::bvisit(const Truncate &x)
 {
     std::vector<llvm::Value *> args;
